@@ -5,26 +5,33 @@
 # This software may be used and distributed according to the terms
 # of the GNU General Public License, incorporated herein by reference.
 
-import os, time
 from revlog import *
+from i18n import gettext as _
+from demandload import demandload
+demandload(globals(), "os time util")
 
 class changelog(revlog):
-    def __init__(self, opener):
-        revlog.__init__(self, opener, "00changelog.i", "00changelog.d")
+    def __init__(self, opener, defversion=REVLOGV0):
+        revlog.__init__(self, opener, "00changelog.i", "00changelog.d",
+                        defversion)
 
     def extract(self, text):
         if not text:
-            return (nullid, "", "0", [], "")
+            return (nullid, "", (0, 0), [], "")
         last = text.index("\n\n")
         desc = text[last + 2:]
         l = text[:last].splitlines()
         manifest = bin(l[0])
         user = l[1]
-        date = l[2]
-        if " " not in date:
-            date += " 0" # some tools used -d without a timezone
+        date = l[2].split(' ')
+        time = float(date.pop(0))
+        try:
+            # various tools did silly things with the time zone field.
+            timezone = int(date[0])
+        except:
+            timezone = 0
         files = l[3:]
-        return (manifest, user, date, files, desc)
+        return (manifest, user, (time, timezone), files, desc)
 
     def read(self, node):
         return self.extract(self.revision(node))
@@ -34,19 +41,18 @@ class changelog(revlog):
         if date:
             # validate explicit (probably user-specified) date and
             # time zone offset. values must fit in signed 32 bits for
-            # current 32-bit linux runtimes.
+            # current 32-bit linux runtimes. timezones go from UTC-12
+            # to UTC+14
             try:
                 when, offset = map(int, date.split(' '))
             except ValueError:
-                raise ValueError('invalid date: %r' % date)
+                raise ValueError(_('invalid date: %r') % date)
             if abs(when) > 0x7fffffff:
-                raise ValueError('date exceeds 32 bits: %d' % when)
-            if abs(offset) >= 43200:
-                raise ValueError('impossible time zone offset: %d' % offset)
+                raise ValueError(_('date exceeds 32 bits: %d') % when)
+            if offset < -50400 or offset > 43200:
+                raise ValueError(_('impossible time zone offset: %d') % offset)
         else:
-            if time.daylight: offset = time.altzone
-            else: offset = time.timezone
-            date = "%d %d" % (time.time(), offset)
+            date = "%d %d" % util.makedate()
         list.sort()
         l = [hex(manifest), user, date] + list + ["", desc]
         text = "\n".join(l)
