@@ -7,7 +7,7 @@ This software may be used and distributed according to the terms
 of the GNU General Public License, incorporated herein by reference.
 """
 
-import sha, binascii
+import binascii
 
 nullid = "\0" * 20
 
